@@ -216,14 +216,25 @@ def build(path, name="goldilox", image=None, dockerfile=None, platform=None):
 @click.argument("path", type=click.Path(exists=True))
 @click.argument('options', nargs=-1, type=click.UNPROCESSED)
 def update(path, **options):
+    """
+    update is a tool for updating metadata and variables for a pipeline file.
+    Please use --file key=file.txt when using files ('requirements' or 'conda_env' keys make sense)
+    Please use --variable key=value to update a variable
+    Example:
+    glx update pipeline.pkl --file requirements=requirements.txt --variable accuracy=0.8
+    """
     options = options['options']
     meta_bytes, state_bytes = Pipeline._read_pipeline_file(path)
     meta = unpickle(meta_bytes)
     variable_flag = '--variable'
+    file_flag = '--file'
     is_variable = False
+    is_file = False
     for option in options:
         if option == variable_flag:
             is_variable = True
+        elif option == file_flag:
+            is_file = True
         else:
             try:
                 key_value = option.split('=')
@@ -237,7 +248,15 @@ def update(path, **options):
                 click.echo(f"variable {key} was update to {value}")
             elif key in meta:
                 tmp_value = value
-                if os.path.isfile(value):
+                if is_file and not os.path.isfile(value):
+                    click.echo(f"{value} is not a file - skip")
+                    is_file = False
+                    continue
+                elif os.path.isfile(value):
+                    click.echo(f"{value} is a file - if you want to load it as such, use '--file {key}={value}'")
+                    click.echo(f"{value} is considered as a string")
+                    is_file = False
+                if is_file and os.path.isfile(value):
                     click.echo(f"{value} is considered as a file")
                     tmp_value = _read_content(value)
                 meta[key] = tmp_value
@@ -246,6 +265,7 @@ def update(path, **options):
                 click.echo(
                     f"{key} was invalid and ignored - for updating a variable use the format '--variable key=value'")
             is_variable = False
+            is_file = False
     state_to_write = Pipeline.BYTES_SIGNETURE + cloudpickle.dumps(meta) + Pipeline.BYTE_DELIMITER + state_bytes
     Pipeline._save_state(path, state_to_write)
 
